odc-stac
========

.. include:: intro.rst

.. toctree::
   :caption: Introduction
   :hidden:
   :maxdepth: 2

   intro.rst

.. toctree::
   :caption: Developer Guide
   :hidden:
   :maxdepth: 2

   api.rst
   examples.rst
   benchmarking.rst

.. toctree::
   :caption: STAC
   :hidden:
   :maxdepth: 2

   stac-vs-odc.rst
   stac-best-practice.rst

.. toctree::
   :caption: Index
   :hidden:
   :maxdepth: 2

   tocs.rst
